package ru.dbotthepony.mc.otm.datagen.lang

import ru.dbotthepony.mc.otm.config.CablesConfig
import ru.dbotthepony.mc.otm.registry.game.AndroidFeatures
import ru.dbotthepony.mc.otm.registry.game.MBlocks
import ru.dbotthepony.mc.otm.registry.game.MEntityTypes
import ru.dbotthepony.mc.otm.registry.game.MItems
import ru.dbotthepony.mc.otm.registry.MRegistry
import ru.dbotthepony.mc.otm.registry.game.MSoundEvents

private const val HIGH_BLAST_RESISTANCE = "Высокая взрывоустойчивость"
private const val HIGH_BLAST_RESISTANCE_DOOR = "Взрывоустойчивая дверь с засовом красного камня..."
private const val FEELING_SAFE_NOW = "...ощущаете ли вы себя теперь в безопасности?"

private fun decoratives(provider: MatteryLanguageProvider) {
	with (provider.russian) {
		for (block in MBlocks.TRITANIUM_ANVIL[null]!!)
			add(block, "Тритановая наковальня")

		for ((color, name) in provider.russianColors.mapped) {
			val nameF = name.replace("ый", "ая").replace("ой", "ая").replace("ий", "яя")

			add(MRegistry.VENT.getBlock(color), "$nameF вентиляция")
			add(MRegistry.VENT_ALTERNATIVE.getBlock(color), "$nameF альтернативная вентиляция")

			for (block in MBlocks.TRITANIUM_ANVIL[color]!!) {
				add(block, "$nameF тритановая наковальня")
			}

			val nameMul = name.replace("ый", "ые").replace("ой", "ые").replace("ий", "ие")
			add(MRegistry.TRITANIUM_BLOCK.getBlock(color), "$name тритановый блок")
			add(MRegistry.COMPUTER_TERMINAL.getBlock(color), "$name компьютерный терминал")
			add(MRegistry.STAR_CHAIR.getBlock(color), "$name звезданутый стул")
			add(MRegistry.STAR_CHAIR.getBlock(color), "desc", "Для длительного наблюдения за звёздами.")
			add(MRegistry.TRITANIUM_STAIRS.getBlock(color), "$name тритановые ступеньки")
			add(MRegistry.TRITANIUM_SLAB.getBlock(color), "$nameF тритановая плита")
			add(MRegistry.TRITANIUM_WALL.getBlock(color), "$nameF тритановая ограда")
			add(MRegistry.FLOOR_TILES.getBlock(color), "$nameF керамическая плитка")
			add(MRegistry.FLOOR_TILES_STAIRS.getBlock(color), "$nameMul ступеньки из керамической плитки")
			add(MRegistry.FLOOR_TILES_SLAB.getBlock(color), "$nameF плита из керамической плитки")
			add(MRegistry.UNREFINED_FLOOR_TILES.getBlock(color), "Необработанная ${nameF.lowercase()} керамическая плитка")

			val nameN = name.replace("ый", "ое").replace("ой", "ое").replace("ий", "ее")
			add(MRegistry.INDUSTRIAL_GLASS.getBlock(color), "$nameN окрашенное промышленное стекло")
			add(MRegistry.INDUSTRIAL_GLASS_PANE.getBlock(color), "$nameF окрашенная промышленная стеклянная панель")

			add(MRegistry.CARGO_CRATES.getBlock(color), "$name грузовой ящик")
			add(MRegistry.DECORATIVE_CRATE.getBlock(color), "$name блок контейнера")

			val nameAdj = name.replace("ый", "ым").replace("ой", "ым").replace("ий", "им").lowercase()
			add(MItems.CARGO_CRATE_MINECARTS[color]!!, "Вагонетка с $nameAdj грузовым ящиком")
			add(MEntityTypes.CARGO_CRATE_MINECARTS[color]!!, "Вагонетка с $nameAdj грузовым ящиком")

			add(MRegistry.TRITANIUM_PRESSURE_PLATE.getBlock(color), "$nameF тритановая нажимная пластина")
			add(MRegistry.TRITANIUM_PRESSURE_PLATE.getBlock(color), "description0", "Активируется только при наступлении игрока на неё")
			add(MRegistry.TRITANIUM_PRESSURE_PLATE.getBlock(color), "description1", HIGH_BLAST_RESISTANCE)

			add(MBlocks.TRITANIUM_DOOR[color]!!, "$nameF тритановая дверь")
			add(MBlocks.TRITANIUM_DOOR[color]!!, "description0", HIGH_BLAST_RESISTANCE_DOOR)
			add(MBlocks.TRITANIUM_DOOR[color]!!, "description1", FEELING_SAFE_NOW)
			add(MBlocks.TRITANIUM_DOOR[color]!!, "description2", "Данный вариант выкрашен в $name")

			add(MBlocks.TRITANIUM_TRAPDOOR[color]!!, "$name тритановый люк")
			add(MBlocks.TRITANIUM_TRAPDOOR[color]!!, "description0", HIGH_BLAST_RESISTANCE_DOOR)
			add(MBlocks.TRITANIUM_TRAPDOOR[color]!!, "description1", FEELING_SAFE_NOW)
			add(MBlocks.TRITANIUM_TRAPDOOR[color]!!, "description2", "Данный вариант выкрашен в $name")

			add(MBlocks.GRILL[color]!!, "$name мангал-дипломат")
		}

		add(MRegistry.TRITANIUM_PRESSURE_PLATE.block, "Тритановая нажимная пластина")
		add(MRegistry.TRITANIUM_PRESSURE_PLATE.block, "description0", "Активируется только при наступлении игрока на неё")
		add(MRegistry.TRITANIUM_PRESSURE_PLATE.block, "description1", HIGH_BLAST_RESISTANCE)

		misc("computer_terminal_tooltip", "Может быть использован как кнопка, с оговоркой что он посылает сигнал блоку сзади, а не под ним")
		misc("computer_terminal_tooltip1", "Для настройки таймера взаимодействуйте будучи крадясь")
		misc("decorative", "Элемент декора")

		add(MBlocks.GRILL[null]!!, "Мангал-дипломат")

		add(MItems.CARGO_CRATE_MINECARTS[null]!!, "Вагонетка с грузовым ящиком")
		add(MEntityTypes.CARGO_CRATE_MINECARTS[null]!!, "Вагонетка с грузовым ящиком")

		add(MRegistry.CARGO_CRATES.block, "Грузовой ящик")
		add(MRegistry.COMPUTER_TERMINAL.block, "Компьютерный терминал")
		add(MRegistry.STAR_CHAIR.block, "Звезданутый стул")
		add(MRegistry.TRITANIUM_BLOCK.block, "Тритановый блок")
		add(MRegistry.TRITANIUM_STAIRS.block, "Тритановые ступеньки")
		add(MRegistry.TRITANIUM_SLAB.block, "Тритановая плита")
		add(MRegistry.TRITANIUM_WALL.block, "Тритановая ограда")

		add(MRegistry.INDUSTRIAL_GLASS.block, "Промышленное стекло")
		add(MRegistry.INDUSTRIAL_GLASS_PANE.block, "Панель промышенного стекла")

		add(MRegistry.DECORATIVE_CRATE.block, "Ржавый грузовой контейнер")

		add(MRegistry.VENT.block, "Вентиляция")
		add(MRegistry.VENT_ALTERNATIVE.block, "Альтернативная вентиляция")

		for ((color, name) in provider.russianColors.mapped) {
			val stripeName = name.replace("ый", "ой").replace("ий", "ей").lowercase()

			add(MBlocks.TRITANIUM_STRIPED_BLOCK[color]!!, "Тритановый блок с $stripeName полоской")
			add(MBlocks.TRITANIUM_STRIPED_STAIRS[color]!!, "Тритановые ступеньки с $stripeName полоской")
			add(MBlocks.TRITANIUM_STRIPED_SLAB[color]!!, "Тритановая плита с $stripeName полоской")
			add(MBlocks.TRITANIUM_STRIPED_WALL[color]!!, "Тритановая ограда с $stripeName полоской")
		}

		for ((block, colors) in MRegistry.TRITANIUM_STRIPED_BLOCK.blocksWithColor) {
			val (base, stripe) = colors

			val baseName = provider.russianColors.mapped[base]!!
			val stripeName = provider.russianColors.mapped[stripe]!!.replace("ый", "ой").replace("ий", "ей").lowercase()

			add(block, "$baseName тритановый блок c $stripeName полоской")
		}

		for ((block, colors) in MRegistry.TRITANIUM_STRIPED_STAIRS.blocksWithColor) {
			val (base, stripe) = colors

			val baseName = provider.russianColors.mapped[base]!!.replace("ый", "ые").replace("ой", "ые").replace("ий", "ие")
			val stripeName = provider.russianColors.mapped[stripe]!!.replace("ый", "ой").replace("ий", "ей").lowercase()

			add(block, "$baseName тритановые ступеньки c $stripeName полоской")
		}

		for ((block, colors) in MRegistry.TRITANIUM_STRIPED_SLAB.blocksWithColor) {
			val (base, stripe) = colors

			val baseName = provider.russianColors.mapped[base]!!.replace("ый", "ая").replace("ой", "ые").replace("ий", "яя")
			val stripeName = provider.russianColors.mapped[stripe]!!.replace("ый", "ой").replace("ий", "ей").lowercase()

			add(block, "$baseName тритановая плита c $stripeName полоской")
		}

		for ((block, colors) in MRegistry.TRITANIUM_STRIPED_WALL.blocksWithColor) {
			val (base, stripe) = colors

			val baseName = provider.russianColors.mapped[base]!!.replace("ый", "ая").replace("ой", "ая").replace("ий", "яя")
			val stripeName = provider.russianColors.mapped[stripe]!!.replace("ый", "ой").replace("ий", "ей").lowercase()

			add(block, "$baseName тритановая ограда c $stripeName полоской")
		}
	}
}

private fun sounds(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		sound("rifle_shot", "Выстрел плазменной винтовки")
		sound("plasma_weapon_overheat", "Плазменное оружие перегрелось")
		sound("player_become_android", "Игрок превратился в андроида")
		sound("projectile_parry", "Снаряд парирован")
		sound("jump_boost", "Усиленный прыжок")
		sound("shockwave", "Ударная волна от приземления")

		sound(MSoundEvents.CARGO_CRATE_OPEN, "Открыт грузовой ящик")
	}
}

private fun misc(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		misc("misc.inert", "Инертен")

		misc("misc.yes", "Да")
		misc("misc.no", "Нет")

		misc("pwr_alert2", "ПТН: ВНИМАНИЕ")
		misc("pwr_alert3", "ПРЕДУПРЕЖДЕНИЕ ОБ ОШИБКЕ:")
		misc("pwr_alert5", "Ошибка %s была обнаружена по адресу %s:%s в %s")

		gui("double_processing", "Обрабатывает два предмета одновременно")

		misc("painted.black", "Окрашено в чёрный")
		misc("painted.blue", "Окрашено в синий")
		misc("painted.brown", "Окрашено в коричневый")
		misc("painted.cyan", "Окрашено в бирюзовый")
		misc("painted.gray", "Окрашено в серый")
		misc("painted.green", "Окрашено в зелёный")
		misc("painted.light_blue", "Окрашено в светло-синий")
		misc("painted.light_gray", "Окрашено в светло-серый")
		misc("painted.lime", "Окрашено в лаймовый")
		misc("painted.magenta", "Окрашено в сиреневый")
		misc("painted.orange", "Окрашено в оранжевый")
		misc("painted.pink", "Окрашено в розовый")
		misc("painted.purple", "Окрашено в фиолетовый")
		misc("painted.red", "Окрашено в красный")
		misc("painted.white", "Окрашено в белый")
		misc("painted.yellow", "Окрашено в жёлтый")

		gui("shift_for_more_info", "<Удерживайте SHIFT для подробностей>")

		gui("help.slot_filters", "Удерживайте CTRL для настройки фильтрации слотов")
		gui("help.slot_charging", "Удерживайте ALT для переключения зарядки слотов")

		gui("needs", "Требуется %s")
		gui("needs_x", "Требуется %s x%d")

		misc("needs_no_power", "Не требует энергии для работы")

		gui("lock_holo_screen", "Заблокировать содержимое")
		gui("lock_holo_screen.unlocked", "Разблокировать содержимое")
		gui("lock_holo_screen.tip", "Блокировка и разблокировка содержимого возможна только в режиме творчества.\nКогда заблокировано, границы ввода текста отключены.")

		gui("holo_screen.resize_text", "Изменять размер текста автоматически")
		gui("holo_screen.do_not_resize_text", "Не менять размер текста")

		gui("abc", "АБВ")
		gui("use_standard_font", "Использовать стандартный шрифт")
		gui("use_small_font", "Использовать уменьшенный шрифт")

		gui("ticks", "Тиков")

		gui("power_cost_per_use", "Энергии на операцию: %s")
		gui("power_cost_per_tick", "Энергии на тик: %s")

		gui("cancel", "Отмена")
		gui("confirm", "Подтвердить")

		gui("recipe.ticks", "%s Тиков")

		gui("exopack", "Инвентарь Экзопака")

		gui("exopack.customize", "Изменить внешний вид Экзопака")
		gui("exopack.customization", "Внешний вид Экзопака")

		gui("exopack.go_back", "Открыть обычный инвентарь")
		gui("exopack.go_in", "Открыть инвентарь Экзопака")
		gui("exopack.toggle_visibility", "Отображать на игроке")
		gui("exopack.toggle_glow", "Свечение в темноте")
		gui("exopack.change_color", "Изменить окраску")
		gui("exopack.change_color2", "Убрать окраску")
		gui("exopack.go_curios", "Открыть инвентарь Curios")

		gui("change_color", "Изменить цвет")

		gui("exopack.probe1", "Данное маленькое устройство необычно на ощупь, а так же неприступно для любых попыток вскрыть.")
		gui("exopack.probe2", "На одной из сторон данного устройства находится сканер отпечатка, который тускло загорается при касании.")
		gui("exopack.probe3", "Вероятно, устройство откроется если достаточно сильно нажать на сканер отпечатка, и вы чувствуете, что последствия будут необратимы!")

		gui("exopack.already_activated", "У вас уже есть Экзопак!")

		gui("exopack_upgrades.no_exopack", "Данный пазл технологии кажется для вас бесполезным... Или..?!")

		gui("exopack_upgrades.already_activated", "Улучшение уже активно!")
		gui("exopack_upgrades.slots_upgrade", "Активируя данное улучшение даст %s слотов в вашем Экзопаке.")
		gui("exopack_upgrades.crafting_upgrade", "Активация данного улучшения даст 3x3 сетку создания в вашем Экзопаке.")
		gui("exopack_upgrades.smelting_upgrade", "Активация данного улучшения даст плавильню в вашем Экзопаке.")
		gui("exopack_upgrades.ender_access_upgrade", "Активация данного улучшения даст доступ к сундуку края в вашем Экзопаке.")

		gui("crude_battery.replace_in_world", "Простота устройства данного аккумулятора позволяет вам заменить ваш внутренний источник питания без станции андроида.")
		gui("crude_battery.replace_in_world_warning", "Данная операция крайне рискованная и может нанести огромный урон вашим системам!")

		gui("power_supplier.active_nodes", "Узлы сети, требующие питания: %s")

		misc("battery.single_use", "Единоразовая батарейка, не может быть перезаряжена.")

		misc("exopack_upgrades.slots_upgraded", "Ваш Экзопак был расширен на %s слотов")
		misc("exopack_upgrades.crafting_upgraded", "Ваш Экзопак получил 3x3 сетку создания")
		misc("exopack_upgrades.smelting_installed", "Ваш Экзопак получил плавильню")
		misc("exopack_upgrades.ender_access_installed", "Ваш Экзопак получил доступ к содержимому сундука края")

		misc("exopack.granted1", "После некоторого времени нажатия на сканер отпечатка, маяк исчезает.")
		misc("exopack.granted2", "Через мгновение, вашу спину пронзают множество раз...")
		misc("exopack.granted3", "Как только боль утихает, вы обнаруживаете нового 'друга' на вашей спине: Экзопак.")
		misc("exopack.granted4", "Данное устройство предоставляет вам доступ к карманному измерению в 4том измерении.")
		misc("exopack.granted5", "Ищите или создавайте модули для улучшения Экзопака.")
		misc("exopack.granted6", "Так же сам Экзопак существует в 4том измерении, что не мешает носить любую броню.")
		misc("exopack.granted7", "Но не смотря на то, что экзопак существует в 4том измерении, предметы из него всё равно высыпаются при смерти.")

		misc("dumping_matter_registry", "Выгружаю реестр материи в %s")
		misc("dumped_matter_registry", "Выгрузил реестр материи в %s")

		misc("iteration", "Итерация %s")
		misc("death_reason", "Списан!")

		misc("item.blackhole_immunity", "Нейтрализует искажение пространства-времени сингулярностями")

		misc("suffix.merge", "%s %s")

		misc("suffix.none", "%s %s")
		misc("suffix.kilo", "%s к%s")
		misc("suffix.mega", "%s М%s")
		misc("suffix.giga", "%s Г%s")
		misc("suffix.tera", "%s Т%s")
		misc("suffix.peta", "%s П%s")
		misc("suffix.exa", "%s Э%s")
		misc("suffix.zetta", "%s З%s")
		misc("suffix.yotta", "%s И%s")
		misc("suffix.ronna", "%s Рн%s")
		misc("suffix.quetta", "%s Кв%s")

		misc("suffix.deci", "%s д%s")
		misc("suffix.centi", "%s с%s")
		misc("suffix.milli", "%s м%s")
		misc("suffix.micro", "%s мк%s")
		misc("suffix.nano", "%s н%s")
		misc("suffix.pico", "%s п%s")
		misc("suffix.femto", "%s ф%s")
		misc("suffix.atto", "%s а%s")
		misc("suffix.zepto", "%s з%s")
		misc("suffix.yocto", "%s и%s")

		misc("suffix_concise.none", "%s")
		misc("suffix_concise.kilo", "%sк")
		misc("suffix_concise.mega", "%sМ")
		misc("suffix_concise.giga", "%sГ")
		misc("suffix_concise.tera", "%sТ")
		misc("suffix_concise.peta", "%sП")
		misc("suffix_concise.exa", "%sЭ")
		misc("suffix_concise.zetta", "%sЗ")
		misc("suffix_concise.yotta", "%sИ")
		misc("suffix_concise.ronna", "%sРн")
		misc("suffix_concise.quetta", "%sКв")

		misc("suffix_concise.deci", "%sд")
		misc("suffix_concise.centi", "%sс")
		misc("suffix_concise.milli", "%sм")
		misc("suffix_concise.micro", "%s к")
		misc("suffix_concise.nano", "%sн")
		misc("suffix_concise.pico", "%sп")
		misc("suffix_concise.femto", "%sф")
		misc("suffix_concise.atto", "%sа")
		misc("suffix_concise.zepto", "%sз")
		misc("suffix_concise.yocto", "%sи")

		misc("suffix_raw.kilo", "к")
		misc("suffix_raw.mega", "М")
		misc("suffix_raw.giga", "Г")
		misc("suffix_raw.tera", "Т")
		misc("suffix_raw.peta", "П")
		misc("suffix_raw.exa", "Э")
		misc("suffix_raw.zetta", "З")
		misc("suffix_raw.yotta", "И")
		misc("suffix_raw.ronna", "Рн")
		misc("suffix_raw.quetta", "Кв")

		misc("suffix_raw.deci", "д")
		misc("suffix_raw.centi", "с")
		misc("suffix_raw.milli", "м")
		misc("suffix_raw.micro", "мк")
		misc("suffix_raw.nano", "н")
		misc("suffix_raw.pico", "п")
		misc("suffix_raw.femto", "ф")
		misc("suffix_raw.atto", "а")
		misc("suffix_raw.zepto", "з")
		misc("suffix_raw.yocto", "и")

		misc("item.power.infinite.storage", "Хранимая энергия неиссякаема")
		misc("item.power.infinite.throughput", "Максимальный ввод/вывод неограничен")
		misc("item.power.passed", "Переданная энергия: %s")
		misc("item.power.received", "Принятая энергия: %s")
		misc("item.power.average", "Среднее: %s в тик")
		misc("item.power.last_20_ticks", "Последняя секунда: %s")
		misc("item.power.last_tick", "Последний тик: %s")

		gui("power.passed", "Всего передано энергии:")
		gui("power.average", "Средняя передача в тик:")
		gui("power.last_20_ticks", "Последняя секунда:")
		gui("power.last_tick", "Последний тик:")

		misc("item.power.storage", "Хранимая энергия: %s / %s")
		misc("item.power.storage0", "Хранимая энергия: %s")
		misc("item.power.throughput", "Максимальная пропускная способность: %s / %s")
		misc("item.power.throughput_mono", "Максимальная пропускная способность: %s")

		misc("item.worker.work_ticks_mono", "Рабочих тиков: %s")
		misc("item.worker.work_ticks", "Рабочих тиков: %s / %s")

		misc("item.block.stored_battery", "Батарея: %s")

		misc("item.pattern.stored", "Хранимые шаблоны: %s / %s")
		misc("item.pattern.infinite.stored", "Хранимые шаблоны: %s")
		misc("item.pattern.research", "Исследовано: %s%%")
		misc("item.pattern.research.item_count", "Предметы: %s / %s")
		misc("item.pattern.research.advance", "Исследование за предмет: %s%%")

		misc("item.matter.storage", "Хранимая материя: %s / %s")
		misc("item.matter.storage0", "Хранимая материя: %s")

		misc("gui.matter_task.total", "Всего: %s")
		misc("gui.matter_task.required", "Осталось исполнить: %s")
		misc("gui.matter_task.in_progress", "В процессе: %s")
		misc("gui.matter_task.finished", "Завершено: %s")

		misc("pill.warning", "ВНИМАНИЕ: Это МГНОВЕННО спишет вас при употреблении!")
		misc("pill.android", "Примешь эту таблетку - войдешь в страну чудес, потеряв то, что удерживает тебя здесь.")

		misc("pill.humane", "Примешь эту таблетку - проснешься в своей постели и поверишь, что это был сон.")

		misc("pill.oblivion", "Предметы и Очки опыта, потраченные на исследования полностью возвращаются.")
		misc("pill.message_oblivion", "Все возможности андроида были удалены, а потраченные на исследования предметы и опыт возвращены.")

		misc("pill.heal", "Даёт регенерацию III на 8 секунд.")
		misc("pill.heal_android", "Не действует на андроидов.")

		misc("pill.not_normal", "Мгновенно убивает существ из плоти")
		misc("pill.suspicious_food.desc", "При более тщательном рассмотрении данная пища выглядит подозрительно...")
		misc("pill.suspicious_food", "Подозрительный %s")

		misc("pill.message", "Ничего не произошло, но вы чувствуете... себя уставшим?.. Возможно надо отдохнуть.")
		misc("pill.message_finish", "§kОДИН ИЗ НАС ОДИН ИЗ НАС ОДИН ИЗ НАС ОДИН ИЗ НАС ОДИН ИЗ НАС")

		gui("power.percentage_level", "Уровень энергии: %s%%")
		gui("power.name", "МтДж")
		gui("fluid.name", "В")
		gui("fluid.level", "%s / %s с %s")

		gui("empty", "Пусто")

		gui("power.burn_time", "Оставшееся время горения: %s тиков")

		gui("progress_widget", "Прогресс: %s%%")
		gui("progress_widget_stuck", "Это устройство не может продолжить работу, проверьте конфигурацию")

		gui("total_raw", "Всего:")
		gui("total", "Всего: %s")
		gui("total_approx", "Всего примерно: %s")

		gui("matter.percentage_level", "Уровень материи: %s%%")
		gui("matter.format", "Материя: %s")
		gui("matter.format_and_complexity", "%s / Сложность: %s")
		gui("matter.format_and_complexity2", "%s (%s) / Сложность: %s (%s)")
		gui("matter.name", "МтЕд")

		gui("flywheel.top", "Как материал сердечника маховой батареи:")
		gui("flywheel.storage", "* Хранилище: %s")
		gui("flywheel.receive_efficiency", "* КПД раскрутки: %s")
		gui("flywheel.momentum_loss_speed", "* Фактор потери накопленной скорости: %s")

		gui("filter.is_whitelist", "Белый список")
		gui("filter.match_nbt", "Сравнивать NBT")
		gui("filter.match_tag", "Сравнить Теги")

		gui("android_research", "Дерево Исследований")

		gui("pattern.percentage_level", "Уровень заполнения: %s%%")
		gui("pattern.format", "Хранимые шаблоны: %s / %s")

		gui("redstone.ignored", "Режим красного камня: Игнорирование")
		gui("redstone.low", "Режим красного камня: Нет сигнала")
		gui("redstone.high", "Режим красного камня: Есть сигнал")

		gui("redstone.ignored.description", "Сигнал красного камня не влияет на работу устройства")
		gui("redstone.low.description", "Устройство работает если нет сигнала красного камня")
		gui("redstone.high.description", "Устройство работает если есть сигнал красного камня")

		misc("3d2d.gravitation_stabilizer.mass", "Масса сингулярности: %s")
		misc("3d2d.gravitation_stabilizer.strength", "Гравитационная сила: %s")

		misc("android_station.research.low_power", "Мало питания у станции андроидов! Исследования недоступны!")
		misc("android_station.research.researched", "Исследовано!")
		misc("android_station.research.can_be_researched", "Готово к исследованию!")
		misc("android_station.research.can_not_afford", "Не хватает предметов!")
		misc("android_station.research.can_not_be_researched", "Нельзя исследовать!")
		misc("android_station.research.xp_cost", "Требуется %s уровней Опыта")
		misc("android_station.research.item", "Требует %s %s шт.")
		misc("android_station.research.missing_predecessors", "Сначала надо изучить %s")

		misc("android_station.research.confirm", "Подтвердите исследование %s")
		misc("android_station.research.research_will_be_blocked", "Следующие исследования станут недоступны:")

		misc("android_station.low_power_0", "Недостаточно питания; Невозможно менять части андроида")
		misc("android_station.low_power_1", "Слабое питание; Невозможно исследовать")
		misc("android_station.power_ok", "Питание в норме")

		misc("filter.yes", "Да")
		misc("filter.no", "Нет")

		misc("matter_bottler.switch_mode", "Переключить режим работы")

		misc("item.quantum_battery.creative", "Наполните этот аккумулятор чтоб выиграть Minecraft.")
		misc("item.quantum_battery.creative2", "Встретимся после выгорания миллионов звёзд.")
		misc("item.quantum_battery.creative_power", "Хранимая энергия: %s / ∞")

		misc("item.quantum_link_id", "ID Квантового соединения: %s")
		misc("item.quantum_description", "Содержимое данного предмета связано с другими предметами посредством квантовой запутанности")
	}
}

private fun death(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		death("otm_become_android", "%1\$s потерял свою человечность")
		death("otm_become_humane", "%1\$s восстановил свою человечность")
		death("otm_event_horizon", "%1\$s никогда не пересёк горизонт событий")
		death("otm_hawking_radiation", "%1\$s открыл излучение Хокинга")
		death("otm_emp", "Электроника %1\$s перегорела")
		death("otm_cosmic_rays", "Электроника %1\$s была ошеломлена космическим излучением")
		death("otm_android_discharge", "В аккумуляторах %1\$s закончился заряд")
		death("otm_not_normal_pill", "%1\$s принял таблетки")
		death("otm_not_normal_pill.item", "%1\$s принял %2\$s")

		death("otm_become_android.player", "%1\$s потерял свою человечность, когда %2\$s пытался образумить их")
		death("otm_become_humane.player", "%1\$s восстановил свою человечность, когда %2\$s пытался образумить их")
		death("otm_event_horizon.player", "%1\$s попытался пересечь горизонт событий, спасаясь от %2\$s")
		death("otm_hawking_radiation.player", "%1\$s распался пока сражался с %2\$s")
		death("otm_emp.player", "%2\$s выбил все предохранители %1\$s")
		death("otm_emp.player.item", "%2\$s выбил все предохранители %1\$s используя %3\$s")

		death("otm_explosive_hammer", "Время развлечений у %1\$s с молотком подошло к концу")
		death("otm_hammer_nail", "%1\$s был пригвождён")
		death("otm_hammer_nail" + ".player", "%1\$s был пригвождён %2\$s")
		death("otm_hammer_nail" + ".player.item", "%1\$s был пригвождён %2\$s используя %3\$s")

		death("otm_exopack_probe", "%1\$s не выдержал спинную хирургию")
		death("otm_exopack_probe.player", "%1\$s не выдержал спинную хирургию пока сражался с %2\$s")
	}
}

private fun blocks(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		addBlock(MBlocks.ANDROID_STATION.values, "Станция андроидов")
		addBlock(MBlocks.ANDROID_STATION.values, "desc", "Даёт доступ к улучшениям андроида")

		addBlock(MBlocks.ANDROID_CHARGER.values, "Беспроводной зарядник")
		addBlock(MBlocks.ANDROID_CHARGER.values, "desc", "Заряжает ближайших андроидов и экзопаки")

		addBlock(MBlocks.BATTERY_BANK.values, "Банк аккумуляторов")
		addBlock(MBlocks.BATTERY_BANK.values, "desc", "Позволяет использовать аккумуляторы как обычное хранилище энергии")

		addBlock(MBlocks.MATTER_DECOMPOSER.values, "Декомпозитор материи")
		addBlock(MBlocks.MATTER_DECOMPOSER.values, "desc", "Разбивает предметы в чистую материю")

		addBlock(MBlocks.MATTER_CAPACITOR_BANK.values, "Банк накопителей материи")
		addBlock(MBlocks.MATTER_CAPACITOR_BANK.values, "desc", "Является хранилищем материи для системы в связке с накопителями материи")

		add(MBlocks.MATTER_CABLE, "Кабель сети материи")

		add(MBlocks.PATTERN_STORAGE, "Хранилище шаблонов")
		add(MBlocks.PATTERN_STORAGE, "desc", "Хранит шаблоны предметов для пользования сетью")

		addBlock(MBlocks.MATTER_SCANNER.values, "Сканер материи")
		addBlock(MBlocks.MATTER_SCANNER.values, "desc", "Сканирует предметы в шаблоны для будущей репликации")

		addBlock(MBlocks.MATTER_PANEL.values, "Монитор шаблонов")
		addBlock(MBlocks.MATTER_PANEL.values, "desc", "Позволяет создавать задачи репликации")

		addBlock(MBlocks.MATTER_REPLICATOR.values, "Репликатор материи")
		addBlock(MBlocks.MATTER_REPLICATOR.values, "desc", "Исполняет задачи репликации")

		addBlock(MBlocks.MATTER_BOTTLER.values, "Бутилировщик материи")
		addBlock(MBlocks.MATTER_BOTTLER.values, "desc", "Позволяет переливать материю между предметами, хранящими материю")

		addBlock(MBlocks.ESSENCE_STORAGE.values, "Хранилище эссенции")
		addBlock(MBlocks.ESSENCE_STORAGE.values, "desc", "Позволяет хранить очки опыта")

		addBlock(MBlocks.MATTER_RECONSTRUCTOR.values, "Материальный реконструктор")
		addBlock(MBlocks.MATTER_RECONSTRUCTOR.values, "desc", "Чинит инструменты используя материю")

		addBlock(MBlocks.MATTER_RECYCLER.values, "Перерабатыватель материи")
		addBlock(MBlocks.MATTER_RECYCLER.values, "desc", "Перерабатывает материальную пыль обратно в чистую материю")

		add(MBlocks.MATTER_ENTANGLER, "Квантовый запутыватель материи")

		add(MBlocks.ENERGY_CABLES[CablesConfig.E.CRUDE]!!, "Самобытный энергетический кабель")
		add(MBlocks.ENERGY_CABLES[CablesConfig.E.REGULAR]!!, "Энергетический кабель")
		add(MBlocks.ENERGY_CABLES[CablesConfig.E.ADVANCED]!!, "Улучшенный энергетический кабель")
		add(MBlocks.ENERGY_CABLES[CablesConfig.E.SUPERCONDUCTOR]!!, "Сверхпроводящий энергетический кабель")

		addBlock(MBlocks.COBBLESTONE_GENERATOR.values, "Генератор булыжника")
		add(MBlocks.INFINITE_WATER_SOURCE, "Неиссякаемый источник воды")
		add(MBlocks.INFINITE_WATER_SOURCE, "desc", "Выталкивает воду в соседние блоки автоматически")

		add(MBlocks.BLACK_HOLE, "Локализированная сингулярная точка аномального искажения пространства-времени")

		add(MBlocks.FLYWHEEL_SHAFT, "Маховый вал")
		add(MBlocks.FLYWHEEL_SHAFT, "desc", "Устанавливается между подшипников")

		add(MBlocks.FLYWHEEL_BEARING, "Маховый подшипник")
		add(MBlocks.FLYWHEEL_BEARING, "desc", "Заменяет центральный блок корпуса сверху и снизу")

		add(MBlocks.FLYWHEEL_BATTERY, "Блок управления маховым хранилищем энергии")
		add(MBlocks.FLYWHEEL_BATTERY, "desc", "Мультиблок, который требует подшипники, корпус, вал, блоки генераторов и ядро из материала на ваше усмотрение")
		add(MBlocks.FLYWHEEL_BATTERY, "desc2", "Имеет неограниченную высоту, с нижним порогом в 4 блока")
		add(MBlocks.FLYWHEEL_BATTERY, "desc3", "Строится как параллелепипед с основной в 5 на 5 блоков")
		add(MBlocks.FLYWHEEL_BATTERY, "desc4", "Использует энергетические *интерфейсы* как порты ввода вывода, и они должны быть установлены на том же")
		add(MBlocks.FLYWHEEL_BATTERY, "desc5", "уровне, что и блоки генераторов")
		add(MBlocks.FLYWHEEL_BATTERY, "desc6", "Важно: должен быть установлен в стене по середине на том же уровне, где находится ядро,")
		add(MBlocks.FLYWHEEL_BATTERY, "desc7", "иначе говоря, он заменяет блок корпуса на высоте одного блока относительно 'пола' структуры")

		add(MBlocks.FLYWHEEL_HOUSING, "Корпус махового хранилища энергии")
		add(MBlocks.FLYWHEEL_HOUSING, "desc", "Мультиблок структура с размерностью 5xNx5")

		add(MBlocks.GENERATOR_BLOCK, "Генераторный блок")
		add(MBlocks.GENERATOR_BLOCK, "desc", "Часть мультиблока, безопасна в качестве декорации")

		add(MBlocks.MODULAR_FRAME, "Модульный каркас")
		add(MBlocks.HEAVY_MODULAR_FRAME, "Тяжёлый модульный каркас")

		add(MBlocks.ENERGY_INPUT_INTERFACE, "Входной энергетический интерфейс")
		add(MBlocks.ENERGY_OUTPUT_INTERFACE, "Выходной энергетический интерфейс")

		add(MBlocks.ENERGY_INPUT_HATCH, "Входной энергетический клапан")
		add(MBlocks.ITEM_INPUT_HATCH, "Входной предметный клапан")
		add(MBlocks.MATTER_INPUT_HATCH, "Входной клапан материи")
		add(MBlocks.ENERGY_OUTPUT_HATCH, "Выходной энергетический клапан")
		add(MBlocks.ITEM_OUTPUT_HATCH, "Выходной предметный клапан")
		add(MBlocks.MATTER_OUTPUT_HATCH, "Выходной клапан материи")

		add(MBlocks.BLACK_HOLE_GENERATOR, "Генератор энергии ускорением материи")
		add(MBlocks.TRITANIUM_HULL, "Тритановый корпус")
		add(MBlocks.TRITANIUM_HULL, "desc", "Прочная часть мультиблока, безопасна в качестве декорации")
		add(MBlocks.MATTER_INJECTOR, "Инжектор материи")
		add(MBlocks.ANTIMATTER_INJECTOR, "Инжектор анти-материи")
		add(MBlocks.HIGH_ENERGY_PARTICLE_COLLECTOR, "Коллектор высокоэнергичных частиц")

		add(MBlocks.DEV_CHEST, "Сундук разработчика")
		add(MBlocks.DEV_CHEST, "desc", "Хранит все предметы, которые есть в игре")
		add(MBlocks.PAINTER, "Стол маляра")

		addBlock(MBlocks.DRIVE_VIEWER.values, "Просмотрщик дисков конденсации")

		add(MBlocks.LIQUID_XP, "Жидкий опыт")
		add(MItems.LIQUID_XP_BUCKET, "Ведро жидкого опыта")

		add(MBlocks.FLUID_TANK, "Жидкостный бак")
		add(MBlocks.FLUID_TANK, "named", "Жидкостный бак (%s)")

		add(MBlocks.ENGINE, "Двигатель корабля")
		add(MBlocks.ENGINE, "desc", "К сожалению, он более не функционирует")

		add(MBlocks.HOLO_SIGN, "Голографическая табличка")
		add(MBlocks.HOLO_SIGN, "desc", "Многострочная, крашеная и светящееся, табличка")

		add(MBlocks.TRITANIUM_INGOT_BLOCK, "Блок слитков тритана")
		add(MBlocks.WITHERED_STEEL_BLOCK, "Блок иссушенной стали")
		add(MBlocks.ROFLITE_ALLOY_BLOCK, "Блок рофлитового сплава")

		addBlock(MBlocks.ENERGY_COUNTER.values, "Счётчик энергии")
		addBlock(MBlocks.ENERGY_COUNTER.values, "desc", "Ограничивает направление передачи энергии;")
		addBlock(MBlocks.ENERGY_COUNTER.values, "desc2", "Позволяет ограничивать максимальную пропускную способность;")
		addBlock(MBlocks.ENERGY_COUNTER.values, "desc3", "Собирает статистику о переданной через себя энергии;")
		addBlock(MBlocks.ENERGY_COUNTER.values, "desc4", "Отображает текущую активность передачи энергии на своём экране")

		add(MBlocks.ENERGY_COUNTER[null]!!, "facing", "Сторона входа: %s")
		add(MBlocks.ENERGY_COUNTER[null]!!, "switch", "Сменить сторону входа")
		add(MBlocks.ENERGY_COUNTER[null]!!, "limit", "Лимит ввода/вывода. -1 для отключения лимитов")
		add(MBlocks.ENERGY_COUNTER[null]!!, "display_this", "Отображать эти данные на экране блока")
		add(MBlocks.ENERGY_COUNTER[null]!!, "do_pull", "Забирать энергию на входе и выталкивать её на выходе")
		add(MBlocks.ENERGY_COUNTER[null]!!, "dont_pull", "Не забирать энергию на входе")

		addBlock(MBlocks.CHEMICAL_GENERATOR.values, "Химический генератор")
		addBlock(MBlocks.CHEMICAL_GENERATOR.values, "desc", "Генерирует энергию сжигая твёрдое топливо")

		add(MBlocks.DRIVE_RACK, "Стеллаж дисков конденсации")
		addBlock(MBlocks.ITEM_MONITOR.values, "Монитор предметов")
		addBlock(MBlocks.PLATE_PRESS.values, "Пресс пластин")
		addBlock(MBlocks.TWIN_PLATE_PRESS.values, "Двойной пресс пластин")

		addBlock(MBlocks.POWERED_FURNACE.values, "Электрическая печь")
		addBlock(MBlocks.POWERED_FURNACE.values, "desc", "Позволяет обрабатывать рецепты печи используя энергию")
		addBlock(MBlocks.POWERED_BLAST_FURNACE.values, "Индукционная печь")
		addBlock(MBlocks.POWERED_BLAST_FURNACE.values, "desc", "Позволяет обрабатывать рецепты плавильной печи используя энергию")
		addBlock(MBlocks.POWERED_SMOKER.values, "Микроволновая печь")
		addBlock(MBlocks.POWERED_SMOKER.values, "desc", "Позволяет обрабатывать рецепты коптильни используя энергию")

		addBlock(MBlocks.ENERGY_SERVO.values, "Энергетическая помпа")
		addBlock(MBlocks.ENERGY_SERVO.values, "desc", "Заряжает, разряжает и передаёт энергию между предметами")

		add(MBlocks.CARBON_FIBRE_BLOCK, "Блок углеродных трубок")
		add(MBlocks.METAL_MESH, "Металлическая решётка")
		add(MBlocks.METAL_JUNK, "Металлический хлам")
		add(MBlocks.METAL_JUNK, "desc", "Бесполезный хлам, или нет?")

		add(MBlocks.TRITANIUM_ORE, "Тритановая руда")
		add(MBlocks.DILITHIUM_ORE, "Дилитевая руда")
		add(MBlocks.DEEPSLATE_TRITANIUM_ORE, "Тританоносный глубинный сланец")
		add(MBlocks.DEEPSLATE_DILITHIUM_ORE, "Глубинный сланец со вкраплением дилития")
		add(MBlocks.TRITANIUM_RAW_BLOCK, "Блок рудного тритана")
		add(MBlocks.DILITHIUM_CRYSTAL_BLOCK, "Блок кристалла дилития")

		add(MBlocks.STORAGE_CABLE, "Кабель хранилища")
		addBlock(MBlocks.STORAGE_POWER_SUPPLIER.values, "Подстанция сети хранилища")
		add(MBlocks.STORAGE_BUS, "Шина хранилища")
		add(MBlocks.STORAGE_IMPORTER, "Импортер хранилища")
		add(MBlocks.STORAGE_EXPORTER, "Экспортер хранилища")

		add(MBlocks.GRAVITATION_STABILIZER, "Стабилизатор пространства-времени")
		add(MBlocks.GRAVITATION_STABILIZER_LENS, "Линза стабилизатора пространства-времени")
		add(MBlocks.GRAVITATION_STABILIZER, "desc", "Уменьшает искажение пространства-времени сингулярностей")
		add(MBlocks.GRAVITATION_STABILIZER, "desc2", "Имейте ввиду, что несколько стабилизаторов создают экспоненциальный эффект")
		add(MBlocks.GRAVITATION_STABILIZER, "desc3", "Слишком слабое искажение пространства-времени приведёт к быстрому 'испарению' сингулярности!")

		add(MBlocks.PHANTOM_ATTRACTOR, "Приманщик фантомов")
		add(MBlocks.PHANTOM_ATTRACTOR, "desc", "Приманивает фантомов в ночное время")

		add(MBlocks.REDSTONE_LAMP_INVERTED, "Лампа (инвертированный сигнал)")
		add(MBlocks.REINFORCED_REDSTONE_LAMP, "Укреплённая лампа")
		add(MBlocks.REINFORCED_REDSTONE_LAMP_INVERTED, "Укреплённая лампа (инвертированный сигнал)")

		add(MBlocks.LABORATORY_LAMP, "Лабораторная лампа")
		add(MBlocks.LABORATORY_LAMP, "description", "Освещает на несколько блоков в направлении своей лампы, с переключателем красного камня")
		add(MBlocks.LABORATORY_LAMP_INVERTED, "Лабораторная лампа (инвентированный сигнал)")
		add(MBlocks.DANGER_STRIPE_BLOCK, "Полоски 'опасность'")
		add(MBlocks.METAL_BEAM, "Металлическая опора")
		add(MBlocks.METAL_BEAM_CENTER, "Металлическая опора (середина)")

		add(MBlocks.TRITANIUM_DOOR[null]!!, "Тритановая дверь")
		add(MBlocks.TRITANIUM_DOOR[null]!!, "description0", "Взрывоустойчивая дверь с засовом красного камня...")
		add(MBlocks.TRITANIUM_DOOR[null]!!, "description1", FEELING_SAFE_NOW)

		add(MBlocks.TRITANIUM_TRAPDOOR[null]!!, "Тритановый люк")
		add(MBlocks.TRITANIUM_TRAPDOOR[null]!!, "description0", "Взрывоустойчивая дверь с засовом красного камня...")
		add(MBlocks.TRITANIUM_TRAPDOOR[null]!!, "description1", FEELING_SAFE_NOW)

		add(MBlocks.TRITANIUM_BARS, "Тритановая решётка")
		add(MBlocks.METAL_RAILING, "Металлические перила")
	}
}

private fun items(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		add(MItems.REDSTONE_INTERACTOR, "Ключ красного камня")
		add(MItems.REDSTONE_INTERACTOR, "desc", "'Посылает' сигнал красного камня из блока, с которым взаимодействует")
		add(MItems.REDSTONE_INTERACTOR, "desc1", "Другими словами, позволяет активировать механизмы красного камня, такие как железные двери")
		add(MItems.REDSTONE_INTERACTOR, "desc2", "Для настройки таймера используйте будучи крадясь")

		add(MItems.PROCEDURAL_BATTERY, "Загадочный аккумулятор")
		add(MItems.PROCEDURAL_BATTERY, "desc", "Данные аккумуляторы можно найти в подземельях, со случайными характеристиками")

		add(MItems.EXPLOSIVE_HAMMER, "Молоток-убийца")
		add(MItems.EXPLOSIVE_HAMMER, "desc", "Для тех, кому стало скучно")
		add(MItems.EXPLOSIVE_HAMMER, "primed", "Заряжен!")
		add(MItems.EXPLOSIVE_HAMMER, "not_primed0", "Не заряжен")
		add(MItems.EXPLOSIVE_HAMMER, "not_primed1", "Для зарядки необходимо немного пороха и наконечник-самородок в вашем инвентаре, и зарядите удерживая ПКМ")

		add(MItems.EXOPACK_PROBE, "Маяк экзопака")
		add(MItems.ExopackUpgrades.INVENTORY_UPGRADE_CREATIVE, "Творческое обновление инвентаря экзопака")
		add(MItems.ExopackUpgrades.CRAFTING_UPGRADE, "Обновление сетки крафта экзопака")
		add(MItems.ExopackUpgrades.SMELTING_UPGRADE, "Модуль плавильни экзопака")
		add(MItems.ExopackUpgrades.ENDER_UPGRADE, "Модуль доступа к сундуку края экзопака")

		add(MItems.ExopackUpgrades.INVENTORY_UPGRADE_WITHER, "Обновление сверхмассивной упаковки")
		add(MItems.ExopackUpgrades.INVENTORY_UPGRADE_WITHER, "description", "Использует те же принципы, которыми обладают звёзды незера")

		add(MItems.ExopackUpgrades.INVENTORY_UPGRADE_ENDER_DRAGON, "Обновление соединения края экзопака")
		add(MItems.ExopackUpgrades.INVENTORY_UPGRADE_ENDER_DRAGON, "description", "Позволяет хранить предметы в карманном измерении. А так же даёт доступ к содержимому сундука края.")

		add(MItems.ExopackUpgrades.INVENTORY_UPGRADE_PROCEDURAL, "Неописуемое обновление инвентаря экзопака")
		add(MItems.ExopackUpgrades.INVENTORY_UPGRADE_PROCEDURAL, "description", "В нормальных условиях, они появляются в сундуках")

		add(MItems.ESSENCE_CAPSULE, "Капсула эссенции")
		add(MItems.ESSENCE_DRIVE, "Голодиск воспоминаний андроида")
		add(MItems.ESSENCE_SERVO, "Помпа эссенции")
		add(MItems.ESSENCE_SERVO, "desc", "Позволяет всасывать близлежащие сферы опыта напрямую в хранилище эссенции")
		add(MItems.ESSENCE_SERVO, "desc2", "Может использоваться как инструмент для ручной перекачки эссенции")

		add(MItems.NUTRIENT_PASTE, "Питательная паста")
		add(MItems.IMPERFECT_BREAD, "Несовершенный хлеб")

		add(MItems.FLUID_CAPSULE, "Жидкостная капсула")
		add(MItems.FLUID_CAPSULE, "named", "Жидкостная капсула (%s)")

		add(MItems.BLACK_HOLE_SCANNER, "Сканер ёярностей")
		add(MItems.BLACK_HOLE_SCANNER, "desc", "Сканирует сингулярности и считывает их свойства")
		add(MItems.BLACK_HOLE_SCANNER, "desc2", "Держите в любой их рук для считывания массы сингулярностей")

		add(MItems.GRAVITATION_FIELD_LIMITER, "Ограничитель искажения пространства-времени")
		add(MItems.GRAVITATION_FIELD_SENSOR, "Сенсор искажения пространства-времени")
		add(MItems.PORTABLE_GRAVITATION_STABILIZER, "Портативный стабилизатор пространства-времени")

		add(MItems.BATTERY_CRUDE, "Самобытный аккумулятор")
		add(MItems.BATTERY_BASIC, "Простой аккумулятор")
		add(MItems.BATTERY_NORMAL, "Аккумулятор")
		add(MItems.BATTERY_DENSE, "Плотный аккумулятор")
		add(MItems.BATTERY_CAPACITOR, "Аккумулятор-конденсатор")
		add(MItems.BATTERY_CREATIVE, "Творческий аккумулятор")

		add(MItems.QUANTUM_BATTERY, "Квантовый аккумулятор")
		add(MItems.QUANTUM_CAPACITOR, "Квантовый аккумулятор-конденсатор")
		add(MItems.QUANTUM_BATTERY_CREATIVE, "Творческий квантовый аккумулятор")

		add(MItems.TRITANIUM_SWORD, "Тритановый меч")
		add(MItems.TRITANIUM_PICKAXE, "Тритановая кирка")
		add(MItems.TRITANIUM_SHOVEL, "Тритановая лопата")
		add(MItems.TRITANIUM_AXE, "Тритановый топор")
		add(MItems.TRITANIUM_HOE, "Тритановая мотыга")
		add(MItems.TRITANIUM_SHEARS, "Тритановые ножницы")
		add(MItems.TRITANIUM_SHIELD, "Тритановый щит")

		add(MItems.WITHERED_STEEL_SWORD, "Меч из иссушенной стали")

		add(MItems.TRITANIUM_HELMET, "Тритановый шлем")
		add(MItems.TRITANIUM_CHESTPLATE, "Тритановый нагрудник")
		add(MItems.TRITANIUM_PANTS, "Тритановые поножи")
		add(MItems.TRITANIUM_BOOTS, "Тритановые ботинки")

		add(MItems.SIMPLE_TRITANIUM_HELMET, "Простой тритановый шлем")
		add(MItems.SIMPLE_TRITANIUM_CHESTPLATE, "Простой тритановый нагрудник")
		add(MItems.SIMPLE_TRITANIUM_PANTS, "Простые тритановые поножи")
		add(MItems.SIMPLE_TRITANIUM_BOOTS, "Простые тритановые ботинки")

		add(MItems.TRITANIUM_DUST, "Тритановая пыль")
		add(MItems.TRITANIUM_INGOT, "Тритановый слиток")
		add(MItems.DILITHIUM_CRYSTAL, "Дилитевый кристалл")
		add(MItems.WITHERED_STEEL, "Слиток иссушенной стали")
		add(MItems.ROFLITE_ALLOY_INGOT, "Слиток рофлитового сплава")
		add(MItems.TRITANIUM_NUGGET, "Тритановый самородок")
		add(MItems.MATTER_IO_PORT, "Порт ввода/вывода материи")
		add(MItems.MATTER_TRANSFORM_MATRIX, "Матрица преобразования материи")
		add(MItems.ANTIMATTER_TRANSFORM_MATRIX, "Матрица преобразования антиматерии")
		add(MItems.ANTIMATTER_TRANSFORM_MATRIX, "desc", "Могут быть найдены в городах Края")
		add(MItems.ENERGY_BUS, "Шина питания")
		add(MItems.ELECTRIC_PARTS, "Электрические части")
		add(MItems.ELECTRIC_PARTS, "desc", "Конденсаторы, резисторы, диоды, перемычки...")
		add(MItems.MECHANICAL_PARTS, "Механические части")
		add(MItems.MECHANICAL_PARTS, "desc", "Подшипники, шестерёнки, муфты, осевые валы...")
		add(MItems.MACHINE_FRAME, "Каркас механизма")
		add(MItems.TRITANIUM_PLATE, "Тритановая пластина")
		add(MItems.IRON_PLATE, "Железная пластина")
		add(MItems.GOLD_PLATE, "Золотая пластина")
		add(MItems.COPPER_WIRING, "Медная проволока")
		add(MItems.GOLD_WIRING, "Золотая проволока")
		add(MItems.PORTABLE_CONDENSATION_DRIVE_CASING, "Каркас портативного диска конденсации")
		add(MItems.PORTABLE_DENSE_CONDENSATION_DRIVE_CASING, "Каркас плотного портативного диска конденсации")
		add(MItems.CIRCUIT_PLATING, "Плата электроники")
		add(MItems.BASIC_CONTROL_CIRCUIT, "Простая схема управления")
		add(MItems.ADVANCED_CONTROL_CIRCUIT, "Продвинутая схема управления")
		add(MItems.QUANTUM_TRANSCEIVER, "Квантовый передатчик")
		add(MItems.ELECTROMAGNET, "Электромагнит")
		add(MItems.ELECTROMOTOR, "Электромотор")
		add(MItems.MIRROR_COMPOUND, "Набор выплавки зеркала")
		add(MItems.MIRROR, "Зеркало")
		add(MItems.MIRROR, "desc", "Я могу очень отчётливо видеть своё отражение в этом зеркале")
		add(MItems.REINFORCED_TRITANIUM_PLATE, "Укреплённая тритановая пластина")
		add(MItems.REINFORCED_TRITANIUM_PLATE, "desc", "Бронированная пластина, усиленная чтобы выдержать большие кинетические силы")
		add(MItems.REINFORCED_IRON_PLATE, "Укреплённая железная пластина")
		add(MItems.REINFORCED_IRON_PLATE, "desc", "Более надёжная и прочная железная пластина")
		add(MItems.ARMOR_ASSEMBLY, "Стройка брони")
		add(MItems.CARBON_MESH, "Углеродная сетка")
		add(MItems.DISPLAY_SCREEN, "Экран дисплея")

		add(MItems.GRAVITATIONAL_DISRUPTOR, "Маяк уравнения пространства-времени")

		add(MItems.GRAVITATIONAL_DISRUPTOR, "description", "Будучи находясь около точки искажения пространства-времени, создаёт противоположное искажение пространства-времени")
		add(MItems.GRAVITATIONAL_DISRUPTOR, "description2", "Позволяет 'уничтожать' сингулярности")
		add(MItems.GRAVITATIONAL_DISRUPTOR, "description3", "Никак не влияет на материю, которую накопила сингулярность, что вызывает неописуемо сильный взрыв материи!")
		add(MItems.GRAVITATIONAL_DISRUPTOR, "description4", "Взрыв %s сдержан %s. Даже не пытайтесь его сдержать.")
		add(MItems.GRAVITATIONAL_DISRUPTOR, "description4_clarification", "не может быть")
		add(MItems.GRAVITATIONAL_DISRUPTOR, "description4_clarification2", "ничем")

		add(MItems.MATTER_DUST, "Пыль материи")
		add(MItems.MATTER_DUST, "desc", "Данный предмет является результатом неудачной попытки декомпозиции или репликации")
		add(MItems.MATTER_DUST, "desc2", "Закиньте в Материальный Переработчик для переработки обратно в чистую материю!")
		add(MItems.MATTER_DUST, "desc3", "Не нюхать, не кидать на других и не сыпать на пончики")

		add(MItems.PILL_ANDROID, "Пилюля андроида")
		add(MItems.PILL_HUMANE, "Пилюля человечности")
		add(MItems.PILL_OBLIVION, "Пилюля сброса андроида до заводских настроек")
		add(MItems.PILL_HEAL, "Медицинская пилюля")
		add(MItems.PILL_NOT_NORMAL, "Не/Нормальная пилюля")

		add(MItems.MATTER_CAPACITOR_PARTS, "Части накопителя материи")
		add(MItems.MATTER_CAPACITOR_BASIC, "Простой накопитель материи")
		add(MItems.MATTER_CAPACITOR_NORMAL, "Накопитель материи")
		add(MItems.MATTER_CAPACITOR_DENSE, "Плотный накопитель материи")
		add(MItems.MATTER_CAPACITOR_CREATIVE, "Творческий накопитель материи")

		add(MItems.ENERGY_SWORD, "Высокочастотный клинок")
		add(MItems.ENERGY_SWORD, "desc", "Требует энергию для работы")
		add(MItems.ENERGY_SWORD, "desc2", "Наносит дополнительный урон андроидам если имеет заряд")
		add(MItems.ENERGY_SWORD, "desc3", "Всегда наносит полный урон по площади если имеет заряд")
		add(MItems.ENERGY_SWORD, "desc4", "Зачарование 'Разящий клинок' не имеет никакого эффекта на данном оружии")

		add(MItems.FALLING_SUN, "◄ Падающее Солнце ►")
		add(MItems.FALLING_SUN, "desc", "Прототип,требует энергию для работы")
		add(MItems.FALLING_SUN, "desc2", "Наносит дополнительный урон андроидам если имеет заряд")
		add(MItems.FALLING_SUN, "desc3", "Всегда наносит полный урон по площади если имеет заряд")
		add(MItems.FALLING_SUN, "desc4", "Зачарование 'Разящий клинок' не имеет никакого эффекта на данном оружии")

		add(MItems.PORTABLE_CONDENSATION_DRIVE, "Portable Condensation Drive")
		add(MItems.PORTABLE_DENSE_CONDENSATION_DRIVE, "Portable Dense Condensation Drive")
		add(MItems.TRITANIUM_ORE_CLUMP, "Рудный тритан")
		add(MItems.PATTERN_DRIVE_NORMAL, "Диск шаблонов")
		add(MItems.PATTERN_DRIVE_DOUBLE, "Двухуровневый диск шаблонов")
		add(MItems.PATTERN_DRIVE_TRIPLE, "Трёхуровневый диск шаблонов")
		add(MItems.PATTERN_DRIVE_QUAD, "Четырёхуровневый диск шаблонов")
		add(MItems.PATTERN_DRIVE_CREATIVE, "Творческий диск шаблонов")

		add(MItems.GOLD_DISK, "Золотой диск")
		add(MItems.GOLD_DISK, "single_item", "Золотой диск (%s)")

		add(MItems.PATTERN_DRIVE_CREATIVE2, "Вездесущий диск шаблонов")
		add(MItems.PATTERN_DRIVE_CREATIVE2, "description1", "Предмет режима творчества")
		add(MItems.PATTERN_DRIVE_CREATIVE2, "description2", "Содержит в себе шаблоны всех предметов, которые имеют значение материи")

		add(MItems.ZPM_BATTERY, "Модуль нулевой точки")
		add(MItems.ZPM_BATTERY, "description", "Может быть найден у тех, кто путешествует между измерениями, если, конечно, они смогли достигнуть вселенной, где данные устройства были созиданы...")

		add(MItems.MachineUpgrades.Basic.BLANK, "Шаблон простого улучшения")
		add(MItems.MachineUpgrades.Basic.SPEED, "Простое улучшение скорости")
		add(MItems.MachineUpgrades.Basic.ENERGY_CONSUMPTION, "Простое улучшение энергоэффективности")
		add(MItems.MachineUpgrades.Basic.FAILSAFE, "Простое улучшение отказоустойчивости")
		add(MItems.MachineUpgrades.Basic.ENERGY_STORAGE, "Простое улучшение энергохранилища")
		add(MItems.MachineUpgrades.Basic.MATTER_STORAGE, "Простое улучшение хранилища материи")
		add(MItems.MachineUpgrades.Basic.PROCESSING_ITEMS, "Простое улучшение обработки")

		add(MItems.MachineUpgrades.Normal.BLANK, "Шаблон улучшения")
		add(MItems.MachineUpgrades.Normal.SPEED, "Улучшение скорости")
		add(MItems.MachineUpgrades.Normal.ENERGY_CONSUMPTION, "Улучшение энергоэффективности")
		add(MItems.MachineUpgrades.Normal.FAILSAFE, "Улучшение отказоустойчивости")
		add(MItems.MachineUpgrades.Normal.ENERGY_STORAGE, "Улучшение энергохранилища")
		add(MItems.MachineUpgrades.Normal.MATTER_STORAGE, "Улучшение хранилища материи")
		add(MItems.MachineUpgrades.Normal.PROCESSING_ITEMS, "Улучшение обработки")

		add(MItems.MachineUpgrades.Advanced.BLANK, "Шаблон продвинутого улучшения")
		add(MItems.MachineUpgrades.Advanced.SPEED, "Продвинутое улучшение скорости")
		add(MItems.MachineUpgrades.Advanced.ENERGY_CONSUMPTION, "Продвинутое улучшение энергоэффективности")
		add(MItems.MachineUpgrades.Advanced.FAILSAFE, "Продвинутое улучшение отказоустойчивости")
		add(MItems.MachineUpgrades.Advanced.ENERGY_STORAGE, "Продвинутое улучшение энергохранилища")
		add(MItems.MachineUpgrades.Advanced.MATTER_STORAGE, "Продвинутое улучшение хранилища материи")
		add(MItems.MachineUpgrades.Advanced.PROCESSING_ITEMS, "Продвинутое улучшение обработки")

		add(MItems.MachineUpgrades.Creative.SPEED, "Творческое улучшение скорости")
		add(MItems.MachineUpgrades.Creative.ENERGY_CONSUMPTION, "Творческое улучшение энергоэффективности")
		add(MItems.MachineUpgrades.Creative.ENERGY_STORAGE, "Творческое улучшение энергохранилища")
		add(MItems.MachineUpgrades.Creative.ENERGY_STORAGE_FLAT, "Творческое улучшение энергохранилища (простое)")
		add(MItems.MachineUpgrades.Creative.ENERGY_STORAGE_FLAT_SMALL, "Творческое улучшение энергохранилища (малое простое)")
		add(MItems.MachineUpgrades.Creative.MATTER_STORAGE, "Творческое улучшение хранилища материи")
		add(MItems.MachineUpgrades.Creative.MATTER_STORAGE_FLAT, "Творческое улучшение хранилища материи (простое)")
		add(MItems.MachineUpgrades.Creative.MATTER_STORAGE_FLAT_SMALL, "Творческое улучшение хранилища материи (малое простое)")
		add(MItems.MachineUpgrades.Creative.ENERGY_THROUGHPUT, "Творческое улучшение энергоканала")
		add(MItems.MachineUpgrades.Creative.ENERGY_THROUGHPUT_FLAT, "Творческое улучшение энергоканала (простое)")
		add(MItems.MachineUpgrades.Creative.ENERGY_THROUGHPUT_FLAT_SMALL, "Творческое улучшение энергоканала (малое простое)")
		add(MItems.MachineUpgrades.Creative.FAILSAFE, "Творческое улучшение отказоустойчивости")
		add(MItems.MachineUpgrades.Creative.FAILURE, "Творческое улучшение краха")
		add(MItems.MachineUpgrades.Creative.PROCESSING_ITEMS, "Творческое улучшение обработки")

		add(MItems.CHEST_UPGRADER, "Ящикатор")
		add(MItems.CHEST_UPGRADER, "desc", "Заменяет установленные сундуки и бочки грузовыми ящиками с сохранением содержимого")
		add(MItems.CHEST_UPGRADER, "desc2", "Удерживайте необходимые ящики в противоположной руке")

		add(MItems.CONFIGURATOR, "Конфигуратор")
		add(MItems.CONFIGURATOR, "desc", "Копирует настройки между блоками")
		add(MItems.CONFIGURATOR, "desc2", "Использование крадясь на блоке копирует настройки, простое использование применяет")
		add(MItems.CONFIGURATOR, "desc3", "Используйте крадясь на воздухе для очистки")
		add(MItems.CONFIGURATOR, "desc_saved", "Сохранены настройки для: %s")

		add(MItems.BREAD_MONSTER_SPAWN_EGG, "Яйцо призыва хлебного монстра")
		add(MEntityTypes.BREAD_MONSTER, "Хлебный монстр")

		add(MItems.LOADER_SPAWN_EGG, "Яйцо призыва погрузчика")
		add(MEntityTypes.LOADER, "Погрузчик")
	}
}

private fun stats(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		stat("health_regenerated", "Здоровья отрегенерировано наноботами")
		stat("damage_absorbed", "Урона поглащено наноботами")
		stat("power_consumed", "МтДж сожжено за андроида")
	}
}

private fun research(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		add("android_research.status.requires", "Требует %s для изучения")
		add("android_research.status.blocks", "Блокирует %s")
		add("android_research.status.blocked_by", "Блокируется %s")
		add("android_research.status.requires_item", "Требует %s")
		add("android_research.status.requires_item_multiple0", "Требует %s %s шт. (требуется ещё %s шт.)")
		add("android_research.status.requires_item_multiple1", "Требует %s %s шт.")

		add("android_research.status.requires_item_any", "Требует любое из %s")
		add("android_research.status.requires_item_multiple_any0", "Требует любое из %s %s шт. (требуется ещё %s шт.)")
		add("android_research.status.requires_item_multiple_any1", "Требует любое из %s %s шт.")
	}
}

private fun androidFeatures(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		add(AndroidFeatures.AIR_BAGS, "Воздушные мешки")
		add(AndroidFeatures.SHOCKWAVE, "Генератор ударных волн")
		add(AndroidFeatures.NIGHT_VISION, "Ночное зрение")
		add(AndroidFeatures.NANOBOTS_ARMOR, "Броня из наноботов")
		add(AndroidFeatures.ITEM_MAGNET, "Предметный магнит")
		add(AndroidFeatures.SWIM_BOOSTERS, "Плавательные лопасти")
		add(AndroidFeatures.STEP_ASSIST, "Помощник подъёма")
		add(AndroidFeatures.JUMP_BOOST, "Усилитель прыжка")
		add(AndroidFeatures.ENDER_TELEPORTER, "Телепортатор края")
	}
}

private fun gui(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		gui("exopack.accept_wireless_charge", "Принимать заряд от беспроводных зарядников")
		gui("exopack.dont_accept_wireless_charge", "Не принимать заряд от беспроводных зарядников")

		gui("charge_androids", "Заряжать андроидов")
		gui("dont_charge_androids", "Не заряжать андроидов")

		gui("charge_exopacks", "Заряжать экзопаки")
		gui("dont_charge_exopacks", "Не заряжать экзопаки")

		gui("multiblock.formed", "Мультиблок сформирован: %s")

		gui("flywheel.current_loss_t", "Текущая потеря энергии в тик:")
		gui("flywheel.current_loss_s", "Текущая потеря энергии в секунду:")
		gui("flywheel.core_material", "Материал сердечника:")
		gui("flywheel.core_material_count", "(Используется блоков сердечника: %s)")

		gui("flow_direction_set", "Направление потока установлено на %s")
		gui("tick_timer_set", "Таймер установлен на %s тиков")

		gui("config_copied", "Скопированы настройки для %s")
		gui("config_pasted", "Настройки применены")
		gui("config_cleared", "Настройки очищены")
		gui("config_missing", "Нет настроек для применения")

		gui("black_hole_generator.help0", "Генерирует электричество используя угловое ускорение сингулярностей")
		gui("black_hole_generator.help1", "Чем сильнее гравитационное поле сингулярности, тем больше генерация!")
		gui("black_hole_generator.help2", "Использование стабилизаторов пространства-времени ослабляет гравитационное поле, снижая генерацию")
		gui("black_hole_generator.help3", "Данный генератор единственный способ 'безопасно' избавиться от сингулярности, полностью лишив её накопленной массы в режиме подпитки антиматерией")

		gui("black_hole_generator.injection_rate.mode", "Скорость подпитки")
		gui("black_hole_generator.target_mass.mode", "Целевая масса")

		gui("black_hole_generator.sustain.mode", "Поддерживать массу")
		gui("black_hole_generator.sustain.desc", "Поддерживать массу сингулярности на заданном значении, подпитывая материей или антиматерией по мере необходимости")

		gui("black_hole_generator.matter_only.mode", "Подпитка материей")
		gui("black_hole_generator.matter_only.desc", "Подпитывать только материей, существенно снизив генерацию энергии, но увеличивая массу сингулярности, а так же дальнейшую выработку энергии")

		gui("black_hole_generator.antimatter_only.mode", "Подпитка антиматерией")
		gui("black_hole_generator.antimatter_only.desc", "Подпитывать только антиматерией, существенно увеличив генерацию энергии, но уменьшая массу сингулярности, а так же дальнейшую выработку энергии")

		gui("draw_multiblock_guide", "Отображать помощника постройки")
		gui("ago", "%s тому назад")

		gui("time.short.5s", "5с")
		gui("time.short.15s", "15с")
		gui("time.short.1m", "1м")
		gui("time.short.10m", "10м")
		gui("time.short.1h", "1ч")
		gui("time.short.6h", "6ч")
		gui("time.short.24h", "24ч")

		gui("part_of_multiblock", "Часть мультиблока, бесполезен сам по себе")
		gui("quicksearch", "Быстрый поиск...")

		gui("painter.is_bulk", "Массовая покраска")
		gui("painter.is_bulk.desc", "Слот покраски будет автоматически наполняться из вашего инвентаря")
		gui("painter.is_bulk.desc2", "Быстрое перемещение покрасит максимальное количество предметов из вашего инвентаря")

		gui("energy_required", "Требуется энергии: %s")

		gui("insert_priority", "Приоритет вставки")
		gui("extract_priority", "Приоритет забора")
		gui("increase", "Увеличить")
		gui("decrease", "Уменьшить")

		gui("color_picker", "Выбор цвета")

		gui("color.short.red", "К")
		gui("color.short.green", "З")
		gui("color.short.blue", "С")
		gui("color.short.hue", "Ц")
		gui("color.short.saturation", "Н")
		gui("color.short.value", "Я")

		gui("color.full.red", "Красный")
		gui("color.full.green", "Зелёный")
		gui("color.full.blue", "Синий")
		gui("color.full.hue", "Цвет")
		gui("color.full.saturation", "Насыщение")
		gui("color.full.value", "Яркость")

		gui("item_monitor.refill_source.desc", "Контролирует источник предметов для заполнения сетки создания")
		gui("item_monitor.refill_source.system", "Только система. Сетка создания будет заполняться только из системы предметов. Данный параметр соответствует поведению AE2 и Refined Storage")
		gui("item_monitor.refill_source.inventory", "Только инвентарь. Сетка создания будет заполняться только из инвентаря игрока")
		gui("item_monitor.refill_source.system_first", "Сначала система. Сетка создания сначала будет заполняться из системы предметов, а затем из инвентаря игрока")
		gui("item_monitor.refill_source.inventory_first", "Сначала инвентарь. Сетка создания сначала будет заполняться из инвентаря игрока, а затем из системы предметов")
		gui("item_monitor.refill_source.do_not", "Не заполнять автоматически")

		gui("item_monitor.result_target.desc", "Контролирует поведение сетки создания")
		gui("item_monitor.result_target.all_system", "Всё в систему. И результат создания и остаток отправляется в систему предметов")
		gui("item_monitor.result_target.mixed", "Смешанный. Результат создания кладётся в инвентарь игрока, остаток отправляется в систему предметов")
		gui("item_monitor.result_target.all_inventory", "Всё в инвентарь. И результат создания и остаток кладётся в инвентарь игрока")

		gui("item_monitor.amount.desc", "Контролирует сколько предметов создавать при быстром крафте")
		gui("item_monitor.amount.one", "Ровно один предмет")
		gui("item_monitor.amount.stack", "Ровно одну стопку. Данный параметр соответствует поведению AE2 и Refined Storage")
		gui("item_monitor.amount.full", "Стопку ингредиентов. Создание продолжается пока не будет достигнут лимит по стопке одного из ингредиентов. Если хотя бы один из ингредиентов не может быть стопкой, будет использован режим 'одна стопка результата'")

		gui("stored_amount", "Точное количество в хранилище: %s шт.")

		gui("sides.item_config", "Предметы")
		gui("sides.energy_config", "Энергия")
		gui("sides.fluid_config", "Жидкости")

		gui("sides.pull_help", "Удерживайте Shift для настройки режима забора")
		gui("sides.push_help", "Удерживайте Ctrl для настройки режима выталкивания")

		gui("sides.top", "Верхняя сторона")
		gui("sides.bottom", "Нижняя сторона")
		gui("sides.front", "Передняя сторона")
		gui("sides.back", "Задняя сторона")
		gui("sides.left", "Левая сторона")
		gui("sides.right", "Правая сторона")

		gui("side_mode.disabled", "Отключено")
		gui("side_mode.input", "Только вход")
		gui("side_mode.output", "Только выход")
		gui("side_mode.input_output", "Вход/Выход")
		gui("side_mode.battery", "Батарея")

		gui("side_mode.pull", "Автоматическое вытягивание")
		gui("side_mode.push", "Автоматическое выталкивание")

		gui("upgrades", "Улучшения")
		gui("upgrades.current", "Активные улучшения:")
		gui("upgrade.speed", "Скорость работы: %s%%")
		gui("upgrade.speed_limit", "Скорость работы: %s%% (предел)")
		gui("upgrade.processing_items", "Работы за цикл: +%s")
		gui("upgrade.energy_storage_flat", "Хранилище энергии: +%s")
		gui("upgrade.matter_storage_flat", "Хранилище материи: +%s")
		gui("upgrade.energy_storage", "Хранилище энергии: +%s%%")
		gui("upgrade.matter_storage", "Хранилище материи: +%s%%")
		gui("upgrade.energy_consumed", "Потребление энергии: %s%%")
		gui("upgrade.energy_consumed_limit", "Потребление энергии: %s%% (предел)")
		gui("upgrade.energy_throughput_flat", "Пропускная способность энергии: +%s")
		gui("upgrade.energy_throughput", "Пропускная способность энергии: +%s%%")
		gui("upgrade.failsafe", "Шанс неудачи: %s%%")

		gui("upgrade_type.list", "Классификация улучшения:")
		gui("upgrade_type.allowed", "Допустимые улучшения:")
		gui("upgrade_type.allowed_none", "На данный момент нет допустимых улучшений.")
		gui("upgrade_type.speed", "Скорость")
		gui("upgrade_type.processing", "Обработка")
		gui("upgrade_type.matter_storage", "Хранилище материи")
		gui("upgrade_type.energy_storage", "Энергохранилище")
		gui("upgrade_type.energy_consumption", "Энергоэффективность")
		gui("upgrade_type.energy_throughput", "Энергоканал")
		gui("upgrade_type.failsafe", "Отказоустойчивость")

		gui("balance_inputs", "Балансировать входные слоты")

		gui("sorting.sort_now", "Отсортировать")
		gui("sorting.sort_settings", "Нажмите правую кнопку мыши для настроек")
		gui("sorting.default", "Сортировка по умолчанию")
		gui("sorting.name", "Сортировка по имени")
		gui("sorting.id", "Сортировка по ID")
		gui("sorting.modid", "Сортировка по пространству имён (моду)")
		gui("sorting.count", "Сортировка по количеству")
		gui("sorting.ascending", "Возрастающая")
		gui("sorting.descending", "Убывающая")
		gui("sorting.matter_value", "Значение материи")
		gui("sorting.matter_complexity", "Сложность репликации")

		gui("matter_panel.send", "Запросить")
		gui("matter_panel.close", "Закрыть")
		gui("matter_panel.cancel_task", "Отменить задание")
		gui("matter_panel.cancel", "Отмена")
		gui("matter_panel.label", "Запрос на репликацию")
		gui("matter_panel.task", "Будущий запрос на репликацию")
		gui("matter_panel.is_providing_tasks", "Задачи передаются на репликаторы")
		gui("matter_panel.not_providing_tasks", "Задачи НЕ передаются на репликаторы")
		gui("matter_panel.cancel_all", "Отменить все задачи")
		gui("matter_panel.cancel_all.desc", "Вы действительно хотите отменить все задачи репликации?")

		gui("matter_panel.tasks", "Задачи")
		gui("matter_panel.patterns", "Шаблоны")

		gui("matter_panel.number_input", "Введите кол-во единиц репликации")

		gui("matter_panel.matter_stored", "Материи хранится: %s")
		gui("matter_panel.matter_required", "Материи требуется: %s")
		gui("matter_panel.complexity", "Общая сложность: %s")

		gui("experience", "%s очков опыта")
		gui("experience_with_limit", "%s / %s очков опыта")
		gui("experience_levels", "%s уровней опыта")
		gui("experience_levels_with_limit", "%s / %s уровней опыта")

		gui("experience.store", "Передать %s уровней опыта")
		gui("experience.store_all", "Передать все уровни опыта")
		gui("experience.dispense", "Вывести %s уровней опыта")
		gui("experience.dispense_all", "Вывести все уровни опыта")
		gui("experience.set_exact", "Установить уровень опыта в %s")

		gui("essence_capsule", "(Почти) Всё, что вы знали, хранится внутри")
		gui("essence_capsule2", "Данный предмет может быть переработан внутри хранилища эссенции")
		gui("essence_capsule3", "Используйте, чтобы высвободить большую часть хранящихся внутри знаний")
		gui("essence_capsule.digital", "Используйте, чтобы вернуть ваши воспоминания")

		gui("slot_filter.filtered", "Данный слот отфильтрован для автоматизации")
		gui("slot_filter.forbidden", "Данный слот запрещён для взаимодействия средствами автоматизации")
		gui("slot_filter.hint", "Для удаления фильтра нажмите Ctrl + ЛКМ")

		gui("debug.tags.help", "Удерживайте Shift для отображения тегов")
		gui("debug.tags.item.title", "Теги предмета:")
		gui("debug.tags.block.title", "Теги блока:")
	}
}

private fun jade(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		jadeloc("matter_storage", "Хранилище материи")
		jadeloc("mattery_energy", "Хранилище энергии")
		jadeloc("mattery_worker", "Прогресс работы механизма")
		jadeloc("matter_bottler", "Режим бутилировщика материи")
		jadeloc("matter_reconstructor", "Прогресс материального реконструктора")

		jade("mode", "Режим: %s")

		jade("matter_bottler.mode.fill", "Заполнение")
		jade("matter_bottler.mode.drain", "Опустошение")
	}
}

private fun maps(provider: MatteryLanguageProvider) {
	with(provider.russian) {
		map("laboratory", "Карта лаборатории")
		map("wreckage", "Карта кораблекрушения")
	}
}

fun AddRussianLanguage(provider: MatteryLanguageProvider) {
	decoratives(provider)
	blocks(provider)
	sounds(provider)
	misc(provider)
	items(provider)
	gui(provider)
	stats(provider)
	research(provider)
	death(provider)
	androidFeatures(provider)
	jade(provider)
	maps(provider)
}
